# Copyright 2013 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS-IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# This file contains environment-variable overrides to be used in conjunction
# with bdutil_env.sh in order to deploy a bigquery-enabled Hadoop cluster.
# Usage: ./bdutil deploy bigquery_env.sh

GCE_SERVICE_ACCOUNT_SCOPES+=('bigquery')

# Whether or not to install and configure the BigQuery connector.
INSTALL_BIGQUERY_CONNECTOR=true

